@@ -21,7 +21,7 @@ $evh->use_socket($socket);
 $evh->request_handler(sub {
     my $r = shift;
     my $n = "only";
-    my $w = $r->start_streaming("200 OK", [
+    my $w = $r->start_streaming(200, [
         'Content-Type' => 'text/plain',
         'Connection' => 'close',
     ]);
@@ -29,7 +29,7 @@ $evh->request_handler(sub {
     $w->write(\$n);
     $w->write("\n");
     $w->close();
-    $evh->graceful_shutdown(sub { EV::unloop });
+    $evh->graceful_shutdown(sub { EV::break });
 });
 
-EV::loop;
+EV::run;
