@@ -6,7 +6,7 @@ use EV ();
 use Carp ();
 use Socket ();
 
-our $VERSION = '1.506_10';
+our $VERSION = '1.506_11';
 
 require Feersum::Connection;
 require Feersum::Connection::Handle;
@@ -220,9 +220,8 @@ Feersum adds these extensions (see below for info)
 Note that SCRIPT_NAME is always blank (but defined).  PATH_INFO will contain
 the path part of the requested URI.
 
-For requests with a body (e.g. POST) C<psgi.input> will contain a valid
-file-handle.  Feersum currently passes C<undef> for psgi.input when there is
-no body to avoid unnecessary work.
+C<psgi.input> always contains a valid handle.  For requests without a body
+(e.g. GET), reading from it returns 0 (empty stream).
 
     my $r = delete $env->{'psgi.input'};
     $r->read($body, $env->{CONTENT_LENGTH});
@@ -361,7 +360,7 @@ would for a PSGI handler (see above for those).
 
 To read input from a POST/PUT, use the C<psgi.input> item of the env hash.
 
-    if ($req->{REQUEST_METHOD} eq 'POST') {
+    if ($env->{REQUEST_METHOD} eq 'POST') {
         my $body = '';
         my $r = delete $env->{'psgi.input'};
         $r->read($body, $env->{CONTENT_LENGTH});
@@ -427,7 +426,7 @@ Feersum operates on the raw file descriptor and will ignore any userspace
 encryption layer.  To enable TLS, use C<set_tls()> after adding the socket;
 Feersum handles encryption internally via picotls.
 
-A reference to C<$sock> is kept as C<< Feersum->endjinn->{socket} >>.
+A reference to C<$sock> is kept internally to prevent garbage collection.
 
 =item C<< accept_on_fd($fileno) >>
 
@@ -548,7 +547,7 @@ with a 500 error to the client.
 
 =item C<< set_server_name_and_port($host,$port) >>
 
-Override Feersum's notion of what SERVER_HOST and SERVER_PORT should be.
+Override Feersum's notion of what SERVER_NAME and SERVER_PORT should be.
 
 =item C<< set_keepalive($bool) >>
 
