@@ -441,7 +441,7 @@ sub _start_pre_fork {
     if ($self->{_use_reuseport}) {
         for my $sock (@{$self->{_socks} || []}) {
             close($sock)
-                or do { warn "close parent socket after fork: $!"; POSIX::_exit(1); };
+                or warn "close parent socket after fork: $!";
         }
         $self->{sock} = undef;
         $self->{_socks} = [];
@@ -500,8 +500,8 @@ Much like L<Plack::Runner>, but with far fewer options.
 
 =item C<< Feersum::Runner->new(%params) >>
 
-Returns a Feersum::Runner singleton.  Params are only applied for the first
-invocation.
+Returns a Feersum::Runner singleton.  If called again while not running, the
+previous instance is replaced with a new one using the provided params.
 
 =over 8
 
